/**
 * This file contains MIDI drum instrument defenitions for use with the OPL2 library and OPL3 Duo! board. These were
 * converted from the General MIDI timbres by The Fat Man(TM). This file contains the drum instrments only. Notice that
 * these are not rhythm mode drums!
 *
 * Instrument definition is based on Adlib instrument bank format.
 *  0 - Transpose
 *		Tells the number of semi-tones a note that is played using this instrument should be pitched up or down. For
 *		drum instruments that are played in melodic mode this sets the absolute note to be played for the drum sound.
 *
 *  1 - Channel c, operator 1, register 0x20
 *		Tremolo(1) | Vibrato(1) | Sustain(1) | KSR(1) | Frequency multiplier (4)
 *
 *  2 - Channel c, operator 1, register 0x40
 *		Key scale level(2) | Output level(6)
 *
 *  3 - Channel c, operator 1, register 0x60
 *		Attack(4) | Decay(4)
 *
 *  4 - Channel c, operator 1, register 0x80
 *		Sustain(4) | Release(4)
 *
 *  5 - Channel c, register 0xC0
 *		Undefined(4) | Modulation feedback factor(3) | Synth type(1)
 *
 *  6 - Channel c, operator 2, register 0x20
 *  7 - Channel c, operator 2, register 0x40
 *  8 - Channel c, operator 2, register 0x60
 *  9 - Channel c, operator 2, register 0x80
 *
 * 10 - Channel c, operators 1 + 2, register 0xE0
 *		OP1 WaveForm(3) | OP2 Waveform(3)
 *
 * 11 - Channel d, operator 3, register 0x20
 * 12 - Channel d, operator 3, register 0x40
 * 13 - Channel d, operator 3, register 0x60
 * 14 - Channel d, operator 3, register 0x80
 * 15 - Channel d, register 0xC0
 * 16 - Channel d, operator 4, register 0x20
 * 17 - Channel d, operator 4, register 0x40
 * 18 - Channel d, operator 4, register 0x60
 * 19 - Channel d, operator 4, register 0x80
 * 20 - Channel d, operators 3 + 4, register 0xE0
 */

#ifndef _MIDI_DRUM4OP_H_
	#define _MIDI_DRUM4OP_H_

	const unsigned char DRUMINS_CLAP2[21]     PROGMEM = { 0x40, 0x82, 0x00, 0xFF, 0x04, 0x0E, 0x10, 0x06, 0xFF, 0x15, 0x02, 0x00, 0x02, 0xFF, 0x07, 0x01, 0x01, 0x00, 0xFF, 0x08, 0x00 };
	const unsigned char DRUMINS_SCRATCH1[21]  PROGMEM = { 0x00, 0x00, 0x3F, 0x00, 0xF0, 0x00, 0x00, 0x3F, 0x00, 0xF0, 0x00, 0x00, 0x3F, 0x00, 0xF0, 0x00, 0x00, 0x3F, 0x00, 0xF0, 0x00 };
	const unsigned char DRUMINS_SCRATCH2[21]  PROGMEM = { 0x00, 0x00, 0x3F, 0x00, 0xF0, 0x00, 0x00, 0x3F, 0x00, 0xF0, 0x00, 0x00, 0x3F, 0x00, 0xF0, 0x00, 0x00, 0x3F, 0x00, 0xF0, 0x00 };
	const unsigned char DRUMINS_RIMSHOT2[21]  PROGMEM = { 0x31, 0x12, 0x11, 0xF5, 0xFE, 0x06, 0x12, 0xA2, 0xF6, 0xFF, 0x00, 0x01, 0x0F, 0xF9, 0xFF, 0x00, 0x11, 0x00, 0xF8, 0xFF, 0x00 };
	const unsigned char DRUMINS_HIQ[21]       PROGMEM = { 0x49, 0x06, 0x3F, 0x00, 0xF4, 0x00, 0x15, 0x00, 0xF7, 0xF5, 0x03, 0x06, 0x3F, 0x00, 0xF4, 0x01, 0x15, 0x08, 0xF7, 0xF5, 0x03 };
	const unsigned char DRUMINS_WOODBLOK[21]  PROGMEM = { 0x41, 0x06, 0x3F, 0x00, 0xF4, 0x00, 0x12, 0x00, 0xF7, 0xF5, 0x03, 0x06, 0x3F, 0x00, 0xF4, 0x01, 0x12, 0x08, 0xF7, 0xF5, 0x03 };
	const unsigned char DRUMINS_GLOCK[21]     PROGMEM = { 0x3C, 0x05, 0x05, 0xF9, 0x32, 0x0E, 0x04, 0x40, 0xD6, 0xA6, 0x03, 0x05, 0x05, 0xF8, 0x32, 0x01, 0x04, 0x40, 0x74, 0xA6, 0x03 };
	const unsigned char DRUMINS_BASS_DR2[21]  PROGMEM = { 0x23, 0x10, 0x44, 0xF8, 0x77, 0x08, 0x11, 0x00, 0xF3, 0x06, 0x02, 0x00, 0x3F, 0x00, 0xF0, 0x01, 0x00, 0x3F, 0x00, 0xF0, 0x00 };
	const unsigned char DRUMINS_BASS_DR1[21]  PROGMEM = { 0x23, 0x01, 0x07, 0xFD, 0x0C, 0x00, 0x00, 0x00, 0xD6, 0x3C, 0x00, 0x00, 0x00, 0xF6, 0x0C, 0x01, 0x00, 0x00, 0xF6, 0x0C, 0x00 };
	const unsigned char DRUMINS_RIMSHOT[21]   PROGMEM = { 0x2C, 0x12, 0x11, 0xF5, 0xFE, 0x06, 0x12, 0xA2, 0xF6, 0xFF, 0x00, 0x01, 0x0F, 0xF9, 0xFF, 0x00, 0x11, 0x00, 0xF8, 0xFF, 0x00 };
	const unsigned char DRUMINS_SNARE_AC[21]  PROGMEM = { 0x30, 0x00, 0x00, 0xFC, 0x05, 0x0E, 0x00, 0x00, 0xFA, 0x17, 0x02, 0x01, 0x03, 0xFC, 0x07, 0x01, 0x02, 0x03, 0xF8, 0x38, 0x60 };
	const unsigned char DRUMINS_CLAP[21]      PROGMEM = { 0x3A, 0x82, 0x00, 0xFF, 0x04, 0x0E, 0x10, 0x06, 0xFF, 0x15, 0x02, 0x00, 0x02, 0xFF, 0x07, 0x01, 0x01, 0x00, 0xFF, 0x08, 0x00 };
	const unsigned char DRUMINS_SNARE_EL[21]  PROGMEM = { 0x3C, 0x00, 0x00, 0xFC, 0x05, 0x0E, 0x00, 0x00, 0xFA, 0x17, 0x02, 0x00, 0x03, 0xFC, 0x07, 0x01, 0x01, 0x03, 0xF8, 0x38, 0x60 };
	const unsigned char DRUMINS_LO_TOMS[21]   PROGMEM = { 0x30, 0x01, 0x07, 0xFD, 0x0C, 0x00, 0x00, 0x00, 0xD6, 0x3C, 0x00, 0x00, 0x00, 0xF6, 0x0C, 0x01, 0x00, 0x00, 0xF6, 0x06, 0x00 };
	const unsigned char DRUMINS_HIHAT_CL[21]  PROGMEM = { 0x2B, 0x0C, 0x00, 0xF6, 0x08, 0x0A, 0x12, 0x00, 0xFB, 0x47, 0x20, 0x0C, 0x00, 0xF6, 0x08, 0x01, 0x12, 0x00, 0xFB, 0x47, 0x20 };
	const unsigned char DRUMINS_HI_TOMS[21]   PROGMEM = { 0x31, 0x01, 0x07, 0xFD, 0x0C, 0x00, 0x00, 0x00, 0xD6, 0x3C, 0x00, 0x00, 0x00, 0xF6, 0x0C, 0x01, 0x00, 0x00, 0xF6, 0x0C, 0x00 };
	const unsigned char DRUMINS_HIHAT_PL[21]  PROGMEM = { 0x2B, 0x0C, 0x00, 0xF6, 0x08, 0x0A, 0x12, 0x00, 0x7B, 0x47, 0x20, 0x0C, 0x00, 0xF6, 0x08, 0x01, 0x12, 0x00, 0x7B, 0x47, 0x20 };
	const unsigned char DRUMINS_LOW_TOM[21]   PROGMEM = { 0x33, 0x01, 0x07, 0xFD, 0x0C, 0x00, 0x00, 0x00, 0xD6, 0x3C, 0x00, 0x00, 0x00, 0xF6, 0x0C, 0x01, 0x00, 0x00, 0xF6, 0x0C, 0x00 };
	const unsigned char DRUMINS_HIHAT_OP[21]  PROGMEM = { 0x2B, 0x0C, 0x00, 0xF6, 0x02, 0x0A, 0x12, 0x00, 0xCB, 0x43, 0x20, 0x0C, 0x00, 0xF6, 0x02, 0x01, 0x12, 0x15, 0xCB, 0x43, 0x20 };
	const unsigned char DRUMINS_LTOM_MID[21]  PROGMEM = { 0x36, 0x01, 0x07, 0xFD, 0x0C, 0x00, 0x00, 0x00, 0xD6, 0x3C, 0x00, 0x00, 0x00, 0xF6, 0x0C, 0x01, 0x00, 0x00, 0xF6, 0x0C, 0x00 };
	const unsigned char DRUMINS_HTOM_MID[21]  PROGMEM = { 0x39, 0x01, 0x07, 0xFD, 0x0C, 0x00, 0x00, 0x00, 0xD6, 0x3C, 0x00, 0x00, 0x00, 0xF6, 0x0C, 0x01, 0x00, 0x00, 0xF6, 0x0C, 0x00 };
	const unsigned char DRUMINS_CRASH[21]     PROGMEM = { 0x48, 0x01, 0x00, 0xF2, 0x55, 0x0E, 0x41, 0x00, 0xF4, 0x00, 0x00, 0x01, 0x00, 0xF3, 0x00, 0x00, 0x8F, 0x00, 0xF4, 0xA4, 0x00 };
	const unsigned char DRUMINS_TOM_HIGH[21]  PROGMEM = { 0x3C, 0x01, 0x07, 0xFD, 0x0C, 0x00, 0x00, 0x00, 0xD6, 0x3C, 0x00, 0x00, 0x00, 0xF6, 0x0C, 0x01, 0x00, 0x00, 0xF6, 0x0C, 0x00 };
	const unsigned char DRUMINS_RIDE_CY[21]   PROGMEM = { 0x46, 0x0F, 0x00, 0xE4, 0xE4, 0x06, 0x08, 0x0A, 0xF5, 0xE5, 0x13, 0x0F, 0x00, 0xF5, 0x66, 0x01, 0x08, 0x19, 0xF5, 0xA5, 0x13 };
	const unsigned char DRUMINS_TAMBOUR[21]   PROGMEM = { 0x3C, 0x81, 0x00, 0xF9, 0x65, 0x0E, 0x41, 0x00, 0xF2, 0x30, 0x00, 0x46, 0x00, 0xFE, 0x00, 0x00, 0x85, 0x00, 0xF5, 0x55, 0x00 };
	const unsigned char DRUMINS_CYMBAL[21]    PROGMEM = { 0x24, 0x0F, 0x00, 0xE4, 0xE4, 0x06, 0x07, 0x11, 0xF5, 0xE5, 0x13, 0x0F, 0x00, 0xF5, 0x65, 0x01, 0x06, 0x1E, 0xF5, 0xA5, 0x13 };
	const unsigned char DRUMINS_TAMBOU2[21]   PROGMEM = { 0x41, 0x06, 0x00, 0x94, 0xC4, 0x00, 0x04, 0x00, 0xF6, 0xF5, 0x20, 0x02, 0x00, 0xF9, 0x04, 0x00, 0x05, 0x03, 0x97, 0xF7, 0x00 };
	const unsigned char DRUMINS_SPLASH[21]    PROGMEM = { 0x54, 0x8F, 0x03, 0xF2, 0x56, 0x0E, 0x46, 0x00, 0xF4, 0x00, 0x11, 0x8F, 0x00, 0xF3, 0x00, 0x00, 0x42, 0x06, 0xF4, 0xA5, 0x00 };
	const unsigned char DRUMINS_COWBELL[21]   PROGMEM = { 0x3B, 0x11, 0x45, 0xF8, 0x37, 0x08, 0x10, 0x00, 0xF3, 0x05, 0x02, 0x11, 0x05, 0xF8, 0x37, 0x01, 0x10, 0x08, 0xF3, 0x05, 0x00 };
	const unsigned char DRUMINS_CRASH2[21]    PROGMEM = { 0x54, 0x81, 0x00, 0xF3, 0x55, 0x0E, 0x41, 0x00, 0xF4, 0x00, 0x01, 0x41, 0x00, 0xF3, 0x00, 0x00, 0x8F, 0x00, 0xF4, 0xA4, 0x00 };
	const unsigned char DRUMINS_VIBRASLA[21]  PROGMEM = { 0x23, 0x80, 0x00, 0xFF, 0x03, 0x0C, 0x10, 0x00, 0xFF, 0x14, 0x05, 0x80, 0x00, 0xFF, 0x03, 0x01, 0x10, 0x0D, 0xFF, 0x14, 0x05 };
	const unsigned char DRUMINS_RIDE2[21]     PROGMEM = { 0x2C, 0x0F, 0x00, 0xE4, 0xE5, 0x06, 0x08, 0x0A, 0xF5, 0xE7, 0x13, 0x0F, 0x00, 0xF5, 0x66, 0x01, 0x08, 0x19, 0xF6, 0xA8, 0x13 };
	const unsigned char DRUMINS_HI_BONGO[21]  PROGMEM = { 0x43, 0x06, 0xC8, 0xF5, 0x0C, 0x06, 0x02, 0x0B, 0xF5, 0x08, 0x00, 0x06, 0xC5, 0xF5, 0x0C, 0x01, 0x01, 0x03, 0xF5, 0x07, 0x00 };
	const unsigned char DRUMINS_LO_BONGO[21]  PROGMEM = { 0x42, 0x01, 0x8F, 0xFA, 0xBF, 0x06, 0x02, 0x80, 0xC8, 0x96, 0x00, 0x01, 0xCF, 0xFA, 0xBF, 0x01, 0x02, 0x0B, 0xC8, 0x96, 0x00 };
	const unsigned char DRUMINS_MUTECONG[21]  PROGMEM = { 0x3B, 0x01, 0x51, 0xFA, 0x87, 0x06, 0x01, 0x00, 0xFA, 0xB7, 0x00, 0x01, 0x4F, 0xFA, 0x87, 0x01, 0x01, 0x08, 0xFA, 0xB7, 0x00 };
	const unsigned char DRUMINS_OPENCONG[21]  PROGMEM = { 0x33, 0x01, 0x55, 0xFA, 0x8D, 0x06, 0x02, 0x00, 0xF8, 0xB5, 0x00, 0x01, 0x55, 0xFA, 0x8D, 0x01, 0x02, 0x12, 0xF8, 0xB5, 0x00 };
	const unsigned char DRUMINS_LOWCONGA[21]  PROGMEM = { 0x2D, 0x01, 0x59, 0xFA, 0x8D, 0x06, 0x02, 0x00, 0xF8, 0xB6, 0x00, 0x01, 0x59, 0xFA, 0x8D, 0x01, 0x02, 0x12, 0xF8, 0xB6, 0x00 };
	const unsigned char DRUMINS_HI_TIMBA[21]  PROGMEM = { 0x47, 0x01, 0x00, 0xFA, 0x0A, 0x0E, 0x00, 0x00, 0xF9, 0x06, 0x00, 0x01, 0x00, 0xFA, 0x0A, 0x01, 0x00, 0x0D, 0xF9, 0x06, 0x00 };
	const unsigned char DRUMINS_LO_TIMBA[21]  PROGMEM = { 0x3C, 0x00, 0x80, 0xF9, 0x89, 0x0E, 0x00, 0x00, 0xF6, 0x6C, 0x03, 0x00, 0x80, 0xF9, 0x89, 0x01, 0x00, 0x08, 0xF6, 0x6C, 0x00 };
	const unsigned char DRUMINS_HI_AGOGO[21]  PROGMEM = { 0x3A, 0x03, 0x8D, 0xF8, 0x88, 0x0E, 0x0C, 0x00, 0xF6, 0xB6, 0x03, 0x03, 0x88, 0xF8, 0x88, 0x01, 0x0C, 0x12, 0xF8, 0xB8, 0x00 };
	const unsigned char DRUMINS_LO_AGOGO[21]  PROGMEM = { 0x35, 0x03, 0x88, 0xF8, 0x88, 0x0E, 0x0C, 0x03, 0xF6, 0xB6, 0x03, 0x03, 0x88, 0xF8, 0x88, 0x01, 0x0C, 0x0F, 0xF8, 0xB8, 0x03 };
	const unsigned char DRUMINS_CABASA[21]    PROGMEM = { 0x40, 0x0F, 0x40, 0x76, 0x4F, 0x0E, 0x00, 0x08, 0x77, 0x18, 0x20, 0x0F, 0x00, 0x76, 0x4F, 0x01, 0x00, 0x12, 0x77, 0x18, 0x20 };
	const unsigned char DRUMINS_MARACAS[21]   PROGMEM = { 0x47, 0x0F, 0x40, 0xC8, 0x49, 0x0E, 0x02, 0x80, 0x9B, 0x69, 0x22, 0x0F, 0xC0, 0xC8, 0x49, 0x01, 0x0F, 0x19, 0x9B, 0x69, 0x22 };
	const unsigned char DRUMINS_S_WHISTL[21]  PROGMEM = { 0x3D, 0x57, 0xDC, 0xAD, 0x05, 0x0E, 0x87, 0x00, 0x8D, 0x05, 0x03, 0x47, 0xDC, 0xAD, 0x05, 0x01, 0x87, 0x12, 0x8D, 0x05, 0x03 };
	const unsigned char DRUMINS_L_WHISTL[21]  PROGMEM = { 0x3D, 0x57, 0xDC, 0xA8, 0x04, 0x0E, 0x87, 0x00, 0x88, 0x04, 0x03, 0x57, 0xDC, 0xA8, 0x04, 0x01, 0x87, 0x08, 0x88, 0x05, 0x03 };
	const unsigned char DRUMINS_S_GUIRO[21]   PROGMEM = { 0x30, 0x80, 0x00, 0xF6, 0x06, 0x0C, 0x10, 0x00, 0xF6, 0x16, 0x05, 0x00, 0x00, 0x6F, 0x0F, 0x01, 0x00, 0x00, 0x6F, 0x0F, 0x55 };
	const unsigned char DRUMINS_L_GUIRO[21]   PROGMEM = { 0x30, 0x80, 0x00, 0xF6, 0x06, 0x0C, 0x10, 0x00, 0xF6, 0x16, 0x05, 0x00, 0x00, 0x4F, 0x0F, 0x01, 0x00, 0x00, 0x4F, 0x0F, 0x55 };
	const unsigned char DRUMINS_CLAVES[21]    PROGMEM = { 0x45, 0x06, 0x3F, 0x00, 0xF4, 0x00, 0x15, 0x00, 0xF7, 0xF5, 0x03, 0x06, 0x3F, 0x00, 0xF4, 0x01, 0x15, 0x08, 0xF7, 0xF5, 0x03 };
	const unsigned char DRUMINS_HI_WDBLK[21]  PROGMEM = { 0x44, 0x06, 0x3F, 0x00, 0xF4, 0x00, 0x12, 0x00, 0xF7, 0xF5, 0x03, 0x06, 0x3F, 0x00, 0xF4, 0x01, 0x12, 0x08, 0xF7, 0xF5, 0x03 };
	const unsigned char DRUMINS_LO_WDBLK[21]  PROGMEM = { 0x3F, 0x06, 0x3F, 0x00, 0xF4, 0x00, 0x12, 0x00, 0xF7, 0xF5, 0x03, 0x06, 0x3F, 0x00, 0xF4, 0x01, 0x12, 0x08, 0xF7, 0xF5, 0x03 };
	const unsigned char DRUMINS_MU_CUICA[21]  PROGMEM = { 0x4A, 0x01, 0xCD, 0x67, 0x47, 0x08, 0x03, 0x40, 0x67, 0x47, 0x07, 0x01, 0xC0, 0x67, 0x47, 0x01, 0x01, 0x00, 0x65, 0x55, 0x00 };
	const unsigned char DRUMINS_OP_CUICA[21]  PROGMEM = { 0x3C, 0x01, 0x17, 0x67, 0xA7, 0x0A, 0x03, 0x1E, 0x65, 0x35, 0x00, 0x01, 0x9D, 0x77, 0x77, 0x01, 0x01, 0x00, 0x75, 0x05, 0x00 };
	const unsigned char DRUMINS_MU_TRNGL[21]  PROGMEM = { 0x50, 0x0A, 0x40, 0xE0, 0xF0, 0x08, 0x1F, 0x40, 0xFF, 0x05, 0x03, 0x0A, 0x40, 0xE0, 0xF0, 0x01, 0x1F, 0x48, 0xFF, 0x05, 0x03 };
	const unsigned char DRUMINS_OP_TRNGL[21]  PROGMEM = { 0x40, 0x0A, 0x7C, 0xE0, 0xF0, 0x08, 0x1F, 0x40, 0xFF, 0x02, 0x03, 0x0A, 0x7C, 0xF5, 0xE0, 0x01, 0x1F, 0x40, 0xFF, 0x03, 0x03 };
	const unsigned char DRUMINS_SHAKER[21]    PROGMEM = { 0x45, 0x0F, 0x40, 0x7F, 0x4F, 0x0E, 0x00, 0x88, 0x7E, 0x1E, 0x20, 0x0F, 0x40, 0x7F, 0x4F, 0x01, 0x00, 0x14, 0x7E, 0x1E, 0x20 };
	const unsigned char DRUMINS_TRIANGL1[21]  PROGMEM = { 0x37, 0x05, 0x05, 0xF9, 0x32, 0x0E, 0x04, 0x40, 0xD6, 0xA6, 0x03, 0x05, 0x05, 0xF8, 0x32, 0x01, 0x04, 0x40, 0x74, 0xA6, 0x03 };
	const unsigned char DRUMINS_TRIANGL2[21]  PROGMEM = { 0x4B, 0x03, 0x0D, 0xE4, 0xE5, 0x0B, 0x07, 0x11, 0xF5, 0xE7, 0x76, 0x00, 0x1B, 0xF5, 0x66, 0x00, 0x04, 0x15, 0xF6, 0xA8, 0x43 };
	const unsigned char DRUMINS_RIMSHOT3[21]  PROGMEM = { 0x44, 0x03, 0x3F, 0x00, 0xF4, 0x08, 0x15, 0x00, 0xF7, 0xF5, 0x03, 0x03, 0x3F, 0x00, 0xF4, 0x01, 0x15, 0x08, 0xF7, 0xF5, 0x03 };
	const unsigned char DRUMINS_RIMSHOT4[21]  PROGMEM = { 0x30, 0x01, 0x4F, 0xFA, 0x8D, 0x06, 0x02, 0x00, 0xF8, 0xB5, 0x00, 0x01, 0x4F, 0xFA, 0x8D, 0x01, 0x02, 0x12, 0xF8, 0xB5, 0x00 };
	const unsigned char DRUMINS_TAIKO[21]     PROGMEM = { 0x35, 0x01, 0x4F, 0xFA, 0x84, 0x06, 0x00, 0x00, 0xF8, 0xB4, 0x00, 0x01, 0x4F, 0xFA, 0x84, 0x01, 0x00, 0x00, 0xF8, 0xB4, 0x00 };

	// MIDI note number of the first drum sound.
	const unsigned char DRUM_NOTE_BASE = 27;
	const unsigned char NUM_MIDI_DRUMS = 60;

	// Instrument pointer array to access instruments by MIDI program.
	const unsigned char *midiDrums[] = {
		DRUMINS_CLAP2,    DRUMINS_SCRATCH1, DRUMINS_SCRATCH2, DRUMINS_RIMSHOT2, DRUMINS_HIQ,      DRUMINS_WOODBLOK,
		DRUMINS_GLOCK,    DRUMINS_BASS_DR2, DRUMINS_BASS_DR1, DRUMINS_RIMSHOT,  DRUMINS_SNARE_AC, DRUMINS_CLAP,
		DRUMINS_SNARE_EL, DRUMINS_LO_TOMS,  DRUMINS_HIHAT_CL, DRUMINS_HI_TOMS,  DRUMINS_HIHAT_PL, DRUMINS_LOW_TOM,
		DRUMINS_HIHAT_OP, DRUMINS_LTOM_MID, DRUMINS_HTOM_MID, DRUMINS_CRASH,    DRUMINS_TOM_HIGH, DRUMINS_RIDE_CY,
		DRUMINS_TAMBOUR,  DRUMINS_CYMBAL,   DRUMINS_TAMBOU2,  DRUMINS_SPLASH,   DRUMINS_COWBELL,  DRUMINS_CRASH2,
		DRUMINS_VIBRASLA, DRUMINS_RIDE2,    DRUMINS_HI_BONGO, DRUMINS_LO_BONGO, DRUMINS_MUTECONG, DRUMINS_OPENCONG,
		DRUMINS_LOWCONGA, DRUMINS_HI_TIMBA, DRUMINS_LO_TIMBA, DRUMINS_HI_AGOGO, DRUMINS_LO_AGOGO, DRUMINS_CABASA,
		DRUMINS_MARACAS,  DRUMINS_S_WHISTL, DRUMINS_L_WHISTL, DRUMINS_S_GUIRO,  DRUMINS_L_GUIRO,  DRUMINS_CLAVES,
		DRUMINS_HI_WDBLK, DRUMINS_LO_WDBLK, DRUMINS_MU_CUICA, DRUMINS_OP_CUICA, DRUMINS_MU_TRNGL, DRUMINS_OP_TRNGL,
		DRUMINS_SHAKER,   DRUMINS_TRIANGL1, DRUMINS_TRIANGL2, DRUMINS_RIMSHOT3, DRUMINS_RIMSHOT4, DRUMINS_TAIKO
	};

#endif
